==> 0.6.3rc1.zip: dmdirc-client/test/com/dmdirc/commandparser/commands/HelpTest.java <==
/*
 * Copyright (c) 2006-2010 Chris Smith, Shane Mc Cormack, Gregory Holmes
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package com.dmdirc.commandparser.commands;

import com.dmdirc.commandparser.CommandInfo;
import com.dmdirc.commandparser.CommandManager;
import com.dmdirc.commandparser.CommandType;
import com.dmdirc.config.IdentityManager;
import com.dmdirc.config.InvalidIdentityFileException;

import java.util.LinkedList;
import java.util.List;
import org.junit.BeforeClass;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.junit.runners.Parameterized;
import static org.junit.Assert.*;

@RunWith(Parameterized.class)
public class HelpTest {

    @BeforeClass
    public static void setUpClass() throws Exception {
        IdentityManager.load();
    }

    private CommandInfo info;

    public HelpTest(final CommandInfo info) {
        this.info = info;
    }

    @Test
    public void testHelp() {
        assertTrue("Command's help output should start with its name ("
                + info.getName() + ")", info.getHelp().startsWith(info.getName()));
    }

    @Parameterized.Parameters
    public static List<Object[]> data() throws InvalidIdentityFileException {
        final List<Object[]> res = new LinkedList<Object[]>();

        IdentityManager.load();
        CommandManager.initCommands();

        for (CommandType type : CommandType.values()) {
            for (CommandInfo command : CommandManager.getCommands(type).keySet()) {
                if (command.showInHelp()) {
                    res.add(new Object[]{command});
                }
            }
        }

        return res;
    }
    
}

==> 0.6.6b1.zip: dmdirc-client/test/com/dmdirc/commandparser/commands/HelpTest.java <==
/*
 * Copyright (c) 2006-2011 DMDirc Developers
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package com.dmdirc.commandparser.commands;

import com.dmdirc.commandparser.CommandInfo;
import com.dmdirc.commandparser.CommandManager;
import com.dmdirc.commandparser.CommandType;
import com.dmdirc.config.IdentityManager;
import com.dmdirc.config.InvalidIdentityFileException;

import java.util.LinkedList;
import java.util.List;
import org.junit.BeforeClass;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.junit.runners.Parameterized;
import static org.junit.Assert.*;

@RunWith(Parameterized.class)
public class HelpTest {

    @BeforeClass
    public static void setUpClass() throws Exception {
        IdentityManager.load();
    }

    private CommandInfo info;

    public HelpTest(final CommandInfo info) {
        this.info = info;
    }

    @Test
    public void testHelp() {
        assertTrue("Command's help output should start with its name ("
                + info.getName() + ")", info.getHelp().startsWith(info.getName()));
    }

    @Parameterized.Parameters
    public static List<Object[]> data() throws InvalidIdentityFileException {
        final List<Object[]> res = new LinkedList<Object[]>();

        IdentityManager.load();
        CommandManager.getCommandManager().initCommands();

        for (CommandType type : CommandType.values()) {
            for (CommandInfo command : CommandManager.getCommandManager().getCommands(type).keySet()) {
                if (command.showInHelp()) {
                    res.add(new Object[]{command});
                }
            }
        }

        return res;
    }
    
}
